@@ -194,7 +194,7 @@ goa_daemon_init (GoaDaemon *daemon)
   goa_error_domain = GOA_ERROR;
   goa_error_domain; /* shut up -Wunused-but-set-variable */
 
-  notify_init ("goa-daemon");
+  notify_init (_("Online Accounts"));
 
   /* TODO: maybe nicer to pass in a GDBusConnection* construct property */
   daemon->connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
@@ -448,7 +448,7 @@ update_account_object (GoaDaemon           *daemon,
   goa_account_set_presentation_identity (account, presentation_identity);
 
   error = NULL;
-  if (!goa_provider_build_object (provider, object, key_file, group, &error))
+  if (!goa_provider_build_object (provider, object, key_file, group, just_added, &error))
     {
       goa_warning ("Error parsing account: %s (%s, %d)",
                    error->message, g_quark_to_string (error->domain), error->code);
@@ -1012,7 +1012,7 @@ on_account_handle_remove (GoaAccount            *account,
       g_set_error_literal (&error,
                            GOA_ERROR,
                            GOA_ERROR_FAILED, /* TODO: more specific */
-                           "ProviderType property is not set for account");
+                           _("ProviderType property is not set for account"));
       g_dbus_method_invocation_return_gerror (invocation, error);
       goto out;
     }
@@ -1024,7 +1024,7 @@ on_account_handle_remove (GoaAccount            *account,
       g_set_error (&error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED, /* TODO: more specific */
-                   "Failed to find a provider for: %s",
+                   _("Failed to find a provider for: %s"),
                    provider_type);
       g_dbus_method_invocation_return_gerror (invocation, error);
       goto out;
