@@ -125,6 +125,35 @@ goa_oauth_provider_get_use_external_browser (GoaOAuthProvider *provider)
 
 /* ---------------------------------------------------------------------------------------------------- */
 
+static gboolean
+goa_oauth_provider_get_use_mobile_browser_default (GoaOAuthProvider  *provider)
+{
+  return FALSE;
+}
+
+/**
+ * goa_oauth_provider_get_use_mobile_browser:
+ * @provider: A #GoaOAuthProvider.
+ *
+ * Returns whether there is a need for the embedded browser to identify
+ * itself as running on a mobile phone in order to get a more compact
+ * version of the approval page.
+ *
+ * This is a virtual method where the default implementation returns
+ * %FALSE.
+ *
+ * Returns: %TRUE if the embedded browser should identify itself as
+ * running on a mobile platform, %FALSE otherwise.
+ */
+gboolean
+goa_oauth_provider_get_use_mobile_browser (GoaOAuthProvider *provider)
+{
+  g_return_val_if_fail (GOA_IS_OAUTH_PROVIDER (provider), FALSE);
+  return GOA_OAUTH_PROVIDER_GET_CLASS (provider)->get_use_mobile_browser (provider);
+}
+
+/* ---------------------------------------------------------------------------------------------------- */
+
 static void
 goa_oauth_provider_add_account_key_values_default (GoaOAuthProvider  *provider,
                                                    GVariantBuilder   *builder)
@@ -665,6 +694,7 @@ rest_proxy_call_cb (RestProxyCall *call, const GError *error, GObject *weak_obje
 
 static gboolean
 get_tokens_and_identity (GoaOAuthProvider *provider,
+                         gboolean          add_account,
                          GtkDialog        *dialog,
                          GtkBox           *vbox,
                          gchar           **out_access_token,
@@ -683,6 +713,7 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
   RestProxy *proxy;
   RestProxyCall *call;
   GHashTable *f;
+  GtkWidget *label;
   GtkWidget *spinner;
   gboolean use_external_browser;
   gchar **request_params;
@@ -732,9 +763,15 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
       goto out;
     }
 
+  label = goa_utils_create_add_refresh_label (GOA_PROVIDER (provider), add_account);
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+  gtk_widget_show (label);
+
   spinner = gtk_spinner_new ();
+  gtk_widget_set_size_request (GTK_WIDGET (spinner), 24, 24);
   gtk_spinner_start (GTK_SPINNER (spinner));
-  gtk_box_pack_start (vbox, spinner, TRUE, TRUE, 0);
+  gtk_box_pack_start (vbox, spinner, TRUE, FALSE, 0);
   gtk_widget_show (spinner);
 
   g_main_loop_run (data.loop);
@@ -816,6 +853,9 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
       web_view = goa_web_view_new ();
       embed = goa_web_view_get_view (GOA_WEB_VIEW (web_view));
 
+      if (goa_oauth_provider_get_use_mobile_browser (provider))
+        goa_web_view_fake_mobile (GOA_WEB_VIEW (web_view));
+
       webkit_web_view_load_uri (WEBKIT_WEB_VIEW (embed), url);
       g_signal_connect (embed,
                         "document-load-finished",
@@ -1017,6 +1057,7 @@ goa_oauth_provider_add_account (GoaProvider *_provider,
   data.loop = g_main_loop_new (NULL, FALSE);
 
   if (!get_tokens_and_identity (provider,
+                                TRUE,
                                 dialog,
                                 vbox,
                                 &access_token,
@@ -1141,6 +1182,7 @@ goa_oauth_provider_refresh_account (GoaProvider  *_provider,
   gtk_widget_show_all (dialog);
 
   if (!get_tokens_and_identity (provider,
+                                FALSE,
                                 GTK_DIALOG (dialog),
                                 GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
                                 &access_token,
@@ -1580,6 +1622,7 @@ goa_oauth_provider_class_init (GoaOAuthProviderClass *klass)
 
   klass->build_authorization_uri  = goa_oauth_provider_build_authorization_uri_default;
   klass->get_use_external_browser = goa_oauth_provider_get_use_external_browser_default;
+  klass->get_use_mobile_browser   = goa_oauth_provider_get_use_mobile_browser_default;
   klass->get_request_uri_params   = goa_oauth_provider_get_request_uri_params_default;
   klass->add_account_key_values   = goa_oauth_provider_add_account_key_values_default;
 }
