@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011 Red Hat, Inc.
+ * Copyright (C) 2011, 2012 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -282,6 +282,7 @@ build_object (GoaProvider         *provider,
               GoaObjectSkeleton   *object,
               GKeyFile            *key_file,
               const gchar         *group,
+              gboolean             just_added,
               GError             **error)
 {
   gboolean ret;
@@ -293,6 +294,7 @@ build_object (GoaProvider         *provider,
                                                                            object,
                                                                            key_file,
                                                                            group,
+                                                                           just_added,
                                                                            error))
     goto out;
 
@@ -315,13 +317,18 @@ show_account (GoaProvider         *provider,
               GoaClient           *client,
               GoaObject           *object,
               GtkBox              *vbox,
-              GtkTable            *table)
+              GtkGrid             *left,
+              GtkGrid             *right)
 {
   /* Chain up */
-  GOA_PROVIDER_CLASS (goa_yahoo_provider_parent_class)->show_account (provider, client, object, vbox, table);
+  GOA_PROVIDER_CLASS (goa_yahoo_provider_parent_class)->show_account (provider,
+                                                                      client,
+                                                                      object,
+                                                                      vbox,
+                                                                      left,
+                                                                      right);
 
   /* TODO: look up email address / screenname from GUID */
-  goa_util_add_row_editable_label_from_keyfile (table, object, _("Name"), "PresentationIdentity", FALSE);
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
